from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import pages_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class PagesStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreatePlace: grpc.UnaryUnaryMultiCallable[pages_pb2.CreatePlaceReq, pages_pb2.Page]
    """Creates a place"""
    CreateGuide: grpc.UnaryUnaryMultiCallable[pages_pb2.CreateGuideReq, pages_pb2.Page]
    """Creates a guide"""
    GetPage: grpc.UnaryUnaryMultiCallable[pages_pb2.GetPageReq, pages_pb2.Page]
    """Gets a page"""
    UpdatePage: grpc.UnaryUnaryMultiCallable[pages_pb2.UpdatePageReq, pages_pb2.Page]
    """Edit a page"""
    TransferPage: grpc.UnaryUnaryMultiCallable[pages_pb2.TransferPageReq, pages_pb2.Page]
    """Transfer a page you own to either a group or a community"""
    ListUserPlaces: grpc.UnaryUnaryMultiCallable[pages_pb2.ListUserPlacesReq, pages_pb2.ListUserPlacesRes]
    """Gets a list of places pages a user owns"""
    ListUserGuides: grpc.UnaryUnaryMultiCallable[pages_pb2.ListUserGuidesReq, pages_pb2.ListUserGuidesRes]
    """Gets a list of guide pages a user owns"""

class PagesServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreatePlace(
        self,
        request: pages_pb2.CreatePlaceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> pages_pb2.Page:
        """Creates a place"""

    @abc.abstractmethod
    def CreateGuide(
        self,
        request: pages_pb2.CreateGuideReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> pages_pb2.Page:
        """Creates a guide"""

    @abc.abstractmethod
    def GetPage(
        self,
        request: pages_pb2.GetPageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> pages_pb2.Page:
        """Gets a page"""

    @abc.abstractmethod
    def UpdatePage(
        self,
        request: pages_pb2.UpdatePageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> pages_pb2.Page:
        """Edit a page"""

    @abc.abstractmethod
    def TransferPage(
        self,
        request: pages_pb2.TransferPageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> pages_pb2.Page:
        """Transfer a page you own to either a group or a community"""

    @abc.abstractmethod
    def ListUserPlaces(
        self,
        request: pages_pb2.ListUserPlacesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> pages_pb2.ListUserPlacesRes:
        """Gets a list of places pages a user owns"""

    @abc.abstractmethod
    def ListUserGuides(
        self,
        request: pages_pb2.ListUserGuidesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> pages_pb2.ListUserGuidesRes:
        """Gets a list of guide pages a user owns"""

def add_PagesServicer_to_server(servicer: PagesServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: requests.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import conversations_pb2 as conversations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0erequests.proto\x12\x19org.couchers.api.requests\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x13\x63onversations.proto\"\x8e\x01\n\x14\x43reateHostRequestReq\x12\x14\n\x0chost_user_id\x18\x01 \x01(\x03\x12\x11\n\tfrom_date\x18\x02 \x01(\t\x12\x0f\n\x07to_date\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x1b\n\x0epublic_trip_id\x18\x05 \x01(\x03H\x00\x88\x01\x01\x42\x11\n\x0f_public_trip_id\"\x88\x04\n\x0bHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x16\n\x0esurfer_user_id\x18\x02 \x01(\x03\x12\x14\n\x0chost_user_id\x18\x03 \x01(\x03\x12\x41\n\x06status\x18\x04 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tfrom_date\x18\x06 \x01(\t\x12\x0f\n\x07to_date\x18\x07 \x01(\t\x12\x1c\n\x14last_seen_message_id\x18\x08 \x01(\x03\x12?\n\x0elatest_message\x18\t \x01(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x14\n\x0chosting_city\x18\n \x01(\t\x12\x13\n\x0bhosting_lat\x18\x0b \x01(\x01\x12\x13\n\x0bhosting_lng\x18\x0c \x01(\x01\x12\x16\n\x0ehosting_radius\x18\r \x01(\x01\x12\"\n\x1aneed_host_request_feedback\x18\x0e \x01(\x08\x12\x13\n\x0bis_archived\x18\x0f \x01(\x08\x12\x1b\n\x0epublic_trip_id\x18\x10 \x01(\x03H\x00\x88\x01\x01\x42\x11\n\x0f_public_trip_id\",\n\x11GetHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\"/\n\x14\x43reateHostRequestRes\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\"\x81\x01\n\x15RespondHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\x12\x0c\n\x04text\x18\x03 \x01(\t\"N\n\x1eSetHostRequestArchiveStatusReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x13\n\x0bis_archived\x18\x02 \x01(\x08\"N\n\x1eSetHostRequestArchiveStatusRes\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x13\n\x0bis_archived\x18\x02 \x01(\x08\"\xc2\x02\n\x13ListHostRequestsReq\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x13\n\x0bonly_active\x18\x03 \x01(\x08\x12\x11\n\tonly_sent\x18\x04 \x01(\x08\x12\x15\n\ronly_received\x18\x05 \x01(\x08\x12\x1a\n\ronly_archived\x18\x06 \x01(\x08H\x00\x88\x01\x01\x12\x44\n\tstatus_in\x18\x07 \x03(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\x12=\n\x07sort_by\x18\x08 \x01(\x0e\x32,.org.couchers.api.requests.HostRequestSortBy\x12\x12\n\npage_token\x18\t \x01(\tB\x10\n\x0e_only_archivedJ\x04\x08\x01\x10\x02R\x0flast_request_id\"\x95\x01\n\x13ListHostRequestsRes\x12=\n\rhost_requests\x18\x01 \x03(\x0b\x32&.org.couchers.api.requests.HostRequest\x12\x0f\n\x07no_more\x18\x03 \x01(\x08\x12\x17\n\x0fnext_page_token\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03R\x0flast_request_id\"]\n\x19GetHostRequestMessagesReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x03\x12\x0e\n\x06number\x18\x03 \x01(\r\"\x80\x01\n\x19GetHostRequestMessagesRes\x12\x39\n\x08messages\x18\x01 \x03(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x17\n\x0flast_message_id\x18\x04 \x01(\x03\x12\x0f\n\x07no_more\x18\x05 \x01(\x08\"B\n\x19SendHostRequestMessageReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\"o\n\x18GetHostRequestUpdatesReq\x12\x19\n\x11newest_message_id\x18\x01 \x01(\x03\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x11\n\tonly_sent\x18\x03 \x01(\x08\x12\x15\n\ronly_received\x18\x04 \x01(\x08\"\xa9\x01\n\x11HostRequestUpdate\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\"j\n\x18GetHostRequestUpdatesRes\x12=\n\x07updates\x18\x01 \x03(\x0b\x32,.org.couchers.api.requests.HostRequestUpdate\x12\x0f\n\x07no_more\x18\x02 \x01(\x08\"S\n\x1aMarkLastSeenHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x1c\n\x14last_seen_message_id\x18\x02 \x01(\x03\"%\n\x12GetResponseRateReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\"\x1e\n\x1cResponseRateInsufficientData\"\x11\n\x0fResponseRateLow\"H\n\x10ResponseRateSome\x12\x34\n\x11response_time_p33\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"~\n\x10ResponseRateMost\x12\x34\n\x11response_time_p33\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11response_time_p66\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x83\x01\n\x15ResponseRateAlmostAll\x12\x34\n\x11response_time_p33\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11response_time_p66\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xf8\x02\n\x12GetResponseRateRes\x12T\n\x11insufficient_data\x18\x01 \x01(\x0b\x32\x37.org.couchers.api.requests.ResponseRateInsufficientDataH\x00\x12\x39\n\x03low\x18\x02 \x01(\x0b\x32*.org.couchers.api.requests.ResponseRateLowH\x00\x12;\n\x04some\x18\x03 \x01(\x0b\x32+.org.couchers.api.requests.ResponseRateSomeH\x00\x12;\n\x04most\x18\x04 \x01(\x0b\x32+.org.couchers.api.requests.ResponseRateMostH\x00\x12\x46\n\nalmost_all\x18\x05 \x01(\x0b\x32\x30.org.couchers.api.requests.ResponseRateAlmostAllH\x00\x42\x0f\n\rresponse_rate\"\x9a\x01\n\x1aSendHostRequestFeedbackReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12K\n\x14host_request_quality\x18\x02 \x01(\x0e\x32-.org.couchers.api.requests.HostRequestQuality\x12\x16\n\x0e\x64\x65\x63line_reason\x18\x03 \x01(\t*]\n\x11HostRequestSortBy\x12$\n HOST_REQUEST_SORT_BY_LAST_ACTIVE\x10\x00\x12\"\n\x1eHOST_REQUEST_SORT_BY_FROM_DATE\x10\x01*\x96\x01\n\x12HostRequestQuality\x12$\n HOST_REQUEST_QUALITY_UNSPECIFIED\x10\x00\x12\x1c\n\x18HOST_REQUEST_QUALITY_LOW\x10\x01\x12\x1d\n\x19HOST_REQUEST_QUALITY_OKAY\x10\x02\x12\x1d\n\x19HOST_REQUEST_QUALITY_HIGH\x10\x03\x32\x91\n\n\x08Requests\x12u\n\x11\x43reateHostRequest\x12/.org.couchers.api.requests.CreateHostRequestReq\x1a/.org.couchers.api.requests.CreateHostRequestRes\x12\x66\n\x0eGetHostRequest\x12,.org.couchers.api.requests.GetHostRequestReq\x1a&.org.couchers.api.requests.HostRequest\x12^\n\x12RespondHostRequest\x12\x30.org.couchers.api.requests.RespondHostRequestReq\x1a\x16.google.protobuf.Empty\x12\x93\x01\n\x1bSetHostRequestArchiveStatus\x12\x39.org.couchers.api.requests.SetHostRequestArchiveStatusReq\x1a\x39.org.couchers.api.requests.SetHostRequestArchiveStatusRes\x12r\n\x10ListHostRequests\x12..org.couchers.api.requests.ListHostRequestsReq\x1a..org.couchers.api.requests.ListHostRequestsRes\x12\x84\x01\n\x16GetHostRequestMessages\x12\x34.org.couchers.api.requests.GetHostRequestMessagesReq\x1a\x34.org.couchers.api.requests.GetHostRequestMessagesRes\x12\x66\n\x16SendHostRequestMessage\x12\x34.org.couchers.api.requests.SendHostRequestMessageReq\x1a\x16.google.protobuf.Empty\x12\x81\x01\n\x15GetHostRequestUpdates\x12\x33.org.couchers.api.requests.GetHostRequestUpdatesReq\x1a\x33.org.couchers.api.requests.GetHostRequestUpdatesRes\x12h\n\x17MarkLastSeenHostRequest\x12\x35.org.couchers.api.requests.MarkLastSeenHostRequestReq\x1a\x16.google.protobuf.Empty\x12o\n\x0fGetResponseRate\x12-.org.couchers.api.requests.GetResponseRateReq\x1a-.org.couchers.api.requests.GetResponseRateRes\x12h\n\x17SendHostRequestFeedback\x12\x35.org.couchers.api.requests.SendHostRequestFeedbackReq\x1a\x16.google.protobuf.Empty\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'requests_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUESTS']._loaded_options = None
  _globals['_REQUESTS']._serialized_options = b'\210\265\030\003'
  _globals['_HOSTREQUESTSORTBY']._serialized_start=3445
  _globals['_HOSTREQUESTSORTBY']._serialized_end=3538
  _globals['_HOSTREQUESTQUALITY']._serialized_start=3541
  _globals['_HOSTREQUESTQUALITY']._serialized_end=3691
  _globals['_CREATEHOSTREQUESTREQ']._serialized_start=180
  _globals['_CREATEHOSTREQUESTREQ']._serialized_end=322
  _globals['_HOSTREQUEST']._serialized_start=325
  _globals['_HOSTREQUEST']._serialized_end=845
  _globals['_GETHOSTREQUESTREQ']._serialized_start=847
  _globals['_GETHOSTREQUESTREQ']._serialized_end=891
  _globals['_CREATEHOSTREQUESTRES']._serialized_start=893
  _globals['_CREATEHOSTREQUESTRES']._serialized_end=940
  _globals['_RESPONDHOSTREQUESTREQ']._serialized_start=943
  _globals['_RESPONDHOSTREQUESTREQ']._serialized_end=1072
  _globals['_SETHOSTREQUESTARCHIVESTATUSREQ']._serialized_start=1074
  _globals['_SETHOSTREQUESTARCHIVESTATUSREQ']._serialized_end=1152
  _globals['_SETHOSTREQUESTARCHIVESTATUSRES']._serialized_start=1154
  _globals['_SETHOSTREQUESTARCHIVESTATUSRES']._serialized_end=1232
  _globals['_LISTHOSTREQUESTSREQ']._serialized_start=1235
  _globals['_LISTHOSTREQUESTSREQ']._serialized_end=1557
  _globals['_LISTHOSTREQUESTSRES']._serialized_start=1560
  _globals['_LISTHOSTREQUESTSRES']._serialized_end=1709
  _globals['_GETHOSTREQUESTMESSAGESREQ']._serialized_start=1711
  _globals['_GETHOSTREQUESTMESSAGESREQ']._serialized_end=1804
  _globals['_GETHOSTREQUESTMESSAGESRES']._serialized_start=1807
  _globals['_GETHOSTREQUESTMESSAGESRES']._serialized_end=1935
  _globals['_SENDHOSTREQUESTMESSAGEREQ']._serialized_start=1937
  _globals['_SENDHOSTREQUESTMESSAGEREQ']._serialized_end=2003
  _globals['_GETHOSTREQUESTUPDATESREQ']._serialized_start=2005
  _globals['_GETHOSTREQUESTUPDATESREQ']._serialized_end=2116
  _globals['_HOSTREQUESTUPDATE']._serialized_start=2119
  _globals['_HOSTREQUESTUPDATE']._serialized_end=2288
  _globals['_GETHOSTREQUESTUPDATESRES']._serialized_start=2290
  _globals['_GETHOSTREQUESTUPDATESRES']._serialized_end=2396
  _globals['_MARKLASTSEENHOSTREQUESTREQ']._serialized_start=2398
  _globals['_MARKLASTSEENHOSTREQUESTREQ']._serialized_end=2481
  _globals['_GETRESPONSERATEREQ']._serialized_start=2483
  _globals['_GETRESPONSERATEREQ']._serialized_end=2520
  _globals['_RESPONSERATEINSUFFICIENTDATA']._serialized_start=2522
  _globals['_RESPONSERATEINSUFFICIENTDATA']._serialized_end=2552
  _globals['_RESPONSERATELOW']._serialized_start=2554
  _globals['_RESPONSERATELOW']._serialized_end=2571
  _globals['_RESPONSERATESOME']._serialized_start=2573
  _globals['_RESPONSERATESOME']._serialized_end=2645
  _globals['_RESPONSERATEMOST']._serialized_start=2647
  _globals['_RESPONSERATEMOST']._serialized_end=2773
  _globals['_RESPONSERATEALMOSTALL']._serialized_start=2776
  _globals['_RESPONSERATEALMOSTALL']._serialized_end=2907
  _globals['_GETRESPONSERATERES']._serialized_start=2910
  _globals['_GETRESPONSERATERES']._serialized_end=3286
  _globals['_SENDHOSTREQUESTFEEDBACKREQ']._serialized_start=3289
  _globals['_SENDHOSTREQUESTFEEDBACKREQ']._serialized_end=3443
  _globals['_REQUESTS']._serialized_start=3694
  _globals['_REQUESTS']._serialized_end=4991
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Messages between main and media server"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import media_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class MediaStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    UploadConfirmation: grpc.UnaryUnaryMultiCallable[media_pb2.UploadConfirmationReq, google.protobuf.empty_pb2.Empty]
    """when an upload completes, the upload server confirms to the main server
    that the upload succeeded using this function
    """

class MediaServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadConfirmation(
        self,
        request: media_pb2.UploadConfirmationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """when an upload completes, the upload server confirms to the main server
        that the upload succeeded using this function
        """

def add_MediaServicer_to_server(servicer: MediaServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2015, Google Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import builtins
import google.api.http_pb2
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

HTTP_FIELD_NUMBER: builtins.int
http: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MethodOptions, google.api.http_pb2.HttpRule]
"""See `HttpRule`."""
